API Reference
=============

.. toctree::
   :maxdepth: 2

   self
   readfish.plugins

``readfish._config`` module
---------------------------

.. module:: readfish._config
.. autoclass:: Conf
   :members:
.. autoclass:: _Condition
   :members:
.. autoclass:: Barcode(...)
.. autoclass:: Region(...)
.. autoclass:: _PluginModule
   :members:
.. autoclass:: CallerSettings(...)
.. autoclass:: MapperSettings(...)
.. .. automodule:: readfish._config
..    :members: Conf, CallerSettings, MapperSettings, Barcode, Region, _Condition, _PluginModule
..    :undoc-members:
..    :show-inheritance:
..    :member-order: bysource

----


``readfish._loggers`` module
----------------------------

.. automodule:: readfish._loggers
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

----


``readfish._utils`` module
--------------------------

.. automodule:: readfish._utils
   :members:
   :undoc-members:
   :show-inheritance:

----


``readfish._cli_args`` module
-----------------------------

.. automodule:: readfish._cli_args
   :members:
   :undoc-members:
   :show-inheritance:

----

``readfish._statistics`` module
--------------------------------

.. automodule:: readfish._statistics
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

----

``readfish._cli_base`` module
-----------------------------

.. automodule:: readfish._cli_base
   :members:
   :undoc-members:
   :show-inheritance:
